==> decoupled_toolbox-1.1.x-dev.tar.gz: decoupled_toolbox/modules/openapi_decoupled_toolbox/src/Entity/OpenApiDecoupledToolbox.php <==
<?php

namespace Drupal\openapi_decoupled_toolbox\Entity;

use Drupal\Core\Config\Entity\ConfigEntityBase;

/**
 * Defines the Open api decoupled toolbox entity.
 *
 * @ConfigEntityType(
 *   id = "open_api_decoupled_toolbox",
 *   label = @Translation("Open api decoupled toolbox"),
 *   handlers = {
 *     "view_builder" = "Drupal\Core\Entity\EntityViewBuilder",
 *     "list_builder" =
 *   "Drupal\openapi_decoupled_toolbox\OpenApiDecoupledToolboxListBuilder",
 *     "form" = {
 *       "add" =
 *   "Drupal\openapi_decoupled_toolbox\Form\OpenApiDecoupledToolboxForm",
 *       "edit" =
 *   "Drupal\openapi_decoupled_toolbox\Form\OpenApiDecoupledToolboxForm",
 *       "delete" =
 *   "Drupal\openapi_decoupled_toolbox\Form\OpenApiDecoupledToolboxDeleteForm"
 *     },
 *     "route_provider" = {
 *       "html" =
 *   "Drupal\openapi_decoupled_toolbox\OpenApiDecoupledToolboxHtmlRouteProvider",
 *     },
 *   },
 *   config_prefix = "open_api_decoupled_toolbox",
 *   admin_permission = "administer site configuration",
 *   entity_keys = {
 *     "id" = "id",
 *     "label" = "label",
 *     "entity_type" = "entity type",
 *     "bundle" = "bundle",
 *     "display" = "display",
 *     "uuid" = "uuid"
 *   },
 *   config_export = {
 *     "id",
 *     "label",
 *     "entity_type",
 *     "bundle",
 *     "display",
 *     "uuid",
 *   },
 *   links = {
 *     "canonical" =
 *   "/admin/structure/open_api_decoupled_toolbox/{open_api_decoupled_toolbox}",
 *     "add-form" = "/admin/structure/open_api_decoupled_toolbox/add",
 *     "edit-form" =
 *   "/admin/structure/open_api_decoupled_toolbox/{open_api_decoupled_toolbox}/edit",
 *     "delete-form" =
 *   "/admin/structure/open_api_decoupled_toolbox/{open_api_decoupled_toolbox}/delete",
 *     "collection" = "/admin/structure/open_api_decoupled_toolbox"
 *   }
 * )
 */
class OpenApiDecoupledToolbox extends ConfigEntityBase implements OpenApiDecoupledToolboxInterface {

  /**
   * The Open api decoupled toolbox ID.
   *
   * @var string
   */
  protected $id;

  /**
   * The Open api decoupled toolbox label.
   *
   * @var string
   */
  protected $label;

  /**
   * @var string
   */
  protected $entity_type;

  /**
   * @var string
   */
  protected $bundle;

  /**
   * @var string
   */
  protected $display;

  public function getTargetEntityType() {
    return $this->entity_type ?? '';
  }

  public function getTargetBundle() {
    return $this->bundle ?? [];
  }

  public function getTargetDisplay() {
    return $this->display ?? [];
  }

}

==> decoupled_toolbox-1.3.x-dev.tar.gz: decoupled_toolbox/modules/openapi_decoupled_toolbox/src/Entity/OpenApiDecoupledToolbox.php <==
<?php

namespace Drupal\openapi_decoupled_toolbox\Entity;

use Drupal\Core\Config\Entity\ConfigEntityBase;

/**
 * Defines the Open api decoupled toolbox entity.
 *
 * @ConfigEntityType(
 *   id = "open_api_decoupled_toolbox",
 *   label = @Translation("Open api decoupled toolbox"),
 *   handlers = {
 *     "view_builder" = "Drupal\Core\Entity\EntityViewBuilder",
 *     "list_builder" =
 *   "Drupal\openapi_decoupled_toolbox\OpenApiDecoupledToolboxListBuilder",
 *     "form" = {
 *       "add" =
 *   "Drupal\openapi_decoupled_toolbox\Form\OpenApiDecoupledToolboxForm",
 *       "edit" =
 *   "Drupal\openapi_decoupled_toolbox\Form\OpenApiDecoupledToolboxForm",
 *       "delete" =
 *   "Drupal\openapi_decoupled_toolbox\Form\OpenApiDecoupledToolboxDeleteForm"
 *     },
 *     "route_provider" = {
 *       "html" =
 *   "Drupal\openapi_decoupled_toolbox\OpenApiDecoupledToolboxHtmlRouteProvider",
 *     },
 *   },
 *   config_prefix = "open_api_decoupled_toolbox",
 *   admin_permission = "administer site configuration",
 *   entity_keys = {
 *     "id" = "id",
 *     "label" = "label",
 *     "entity_type" = "entity type",
 *     "bundle" = "bundle",
 *     "display" = "display",
 *     "uuid" = "uuid"
 *   },
 *   config_export = {
 *     "id",
 *     "label",
 *     "entity_type",
 *     "bundle",
 *     "display",
 *     "uuid",
 *   },
 *   links = {
 *     "canonical" =
 *   "/admin/structure/open_api_decoupled_toolbox/{open_api_decoupled_toolbox}",
 *     "add-form" = "/admin/structure/open_api_decoupled_toolbox/add",
 *     "edit-form" =
 *   "/admin/structure/open_api_decoupled_toolbox/{open_api_decoupled_toolbox}/edit",
 *     "delete-form" =
 *   "/admin/structure/open_api_decoupled_toolbox/{open_api_decoupled_toolbox}/delete",
 *     "collection" = "/admin/structure/open_api_decoupled_toolbox"
 *   }
 * )
 */
class OpenApiDecoupledToolbox extends ConfigEntityBase implements OpenApiDecoupledToolboxInterface {

  /**
   * The Open api decoupled toolbox ID.
   *
   * @var string
   */
  protected $id;

  /**
   * The Open api decoupled toolbox label.
   *
   * @var string
   */
  protected $label;

  /**
   * @var string
   */
  protected $entity_type;

  /**
   * @var array
   */
  protected $bundle;

  /**
   * @var array
   */
  protected $display;

  public function getTargetEntityType() {
    return $this->entity_type ?? '';
  }

  public function getTargetBundle() {
    return $this->bundle ?array_filter($this->bundle): [];
  }

  public function getTargetDisplay() {
    return $this->display ?array_filter($this->display): [];
  }

}
